@@ -8,6 +8,7 @@ from bids import BIDSLayout, exceptions
 from rich.progress import Progress, SpinnerColumn, TextColumn, track
 
 from bagel import mappings, models
+from bagel._version import __version__
 
 from .logger import VerbosityLevel, configure_logger, log_error, logger
 from .utilities import (
@@ -19,18 +20,29 @@ from .utilities import (
 )
 from .utilities.derivative_utils import PROC_STATUS_COLS
 
+OPTION_GROUP_NAMES = {
+    "troubleshooting": "Troubleshooting",
+    "config": "Configuration",
+}
+
 CUSTOM_SESSION_LABEL = "ses-unnamed"
 
 bagel = typer.Typer(
-    help="""
-    A command-line tool for creating valid, subject-level instances of the Neurobagel graph data model.\n
-    The 'pheno' command must always be run first to generate the input .jsonld file required for the 'bids' command.
-
-    To view the arguments for a specific command, run: bagel [COMMAND] --help
-    """,
+    help=(
+        "A command-line tool for creating valid, subject-level instances of the Neurobagel graph data model.\n\n"
+        "[red]NOTE: The 'pheno' command must always be run first on a new dataset to generate the input .jsonld file required for the 'bids' command.[/red]"
+    ),
     # From https://github.com/tiangolo/typer/issues/201#issuecomment-744151303
     context_settings={"help_option_names": ["--help", "-h"]},
+    # NOTE: invoking bagel with no options still results in a non-zero exit code
+    # even though the help text is printed and there are no errors,
+    # because required options are still detected as missing
+    no_args_is_help=True,
     rich_markup_mode="rich",
+    epilog=(
+        "Run 'bagel COMMAND --help' for more information on a command.\n\n"
+        "Or visit the documentation at https://neurobagel.org/user_guide/cli/"
+    ),
 )
 
 
@@ -44,6 +56,7 @@ def verbosity_option():
         "-v",
         callback=configure_logger,
         help="Set the verbosity level of the output. 0 = show errors only; 1 = show errors, warnings, and informational messages; 3 = show all logs, including debug messages.",
+        rich_help_panel=OPTION_GROUP_NAMES["troubleshooting"],
     )
 
 
@@ -57,13 +70,60 @@ def overwrite_option():
     )
 
 
+def show_help(ctx: typer.Context, value: bool):
+    """
+    Callback to display the command help and exit.
+    Adapted from https://github.com/fastapi/typer/discussions/833#discussioncomment-9551792.
+    """
+    if value:
+        typer.echo(ctx.get_help())
+        raise typer.Exit()
+
+
+def help_option():
+    """
+    Create a reusable help option for commands.
+    Used to override the default location of the --help option in the help text
+    so that it appears in a different named option group.
+    """
+    return typer.Option(
+        False,
+        "--help",
+        "-h",
+        callback=show_help,
+        help="Show this message and exit.",
+        rich_help_panel=OPTION_GROUP_NAMES["troubleshooting"],
+    )
+
+
+def show_version(value: bool):
+    """Callback to show package version number and exit."""
+    if value:
+        print(f"bagel {__version__}")
+        raise typer.Exit()
+
+
+@bagel.callback()
+def main(
+    version: bool = typer.Option(
+        None,
+        "--version",
+        help="Show the version and exit.",
+        callback=show_version,
+        is_eager=True,
+    )
+):
+    """Handle options for the main CLI command 'bagel'."""
+    return
+
+
 @bagel.command()
 def bids2tsv(
     bids_dir: Path = typer.Option(
         ...,
         "--bids-dir",
         "-b",
-        help="The path to the BIDS dataset directory.",
+        help="Path to the BIDS dataset directory.",
         exists=True,
         file_okay=False,
         dir_okay=True,
@@ -73,17 +133,17 @@ def bids2tsv(
         "bids.tsv",
         "--output",
         "-o",
-        help="The path to save the output .tsv file.",
+        help="Path to save the output .tsv file.",
         file_okay=True,
         dir_okay=False,
         resolve_path=True,
     ),
     overwrite: bool = overwrite_option(),
     verbosity: VerbosityLevel = verbosity_option(),
+    help_: bool = help_option(),
 ):
     """
-    Convert a BIDS dataset into a minimal tabular format (.tsv file) containing information about
-    subject, session, suffix (image contrast), and file path for NIfTI data only.
+    Convert a BIDS dataset into a minimal tabular format (.tsv) containing information about subject, session, suffix (image contrast), and file path for imaging files.
     """
     file_utils.check_overwrite(output, overwrite)
 
@@ -97,7 +157,8 @@ def bids2tsv(
             TextColumn("[progress.description]{task.description}"),
             transient=True,
         ) as progress:
-            # Add a spinner during BIDS parsing
+            # Add a spinner during BIDS parsing - this spinner disappears once the process is done
+            # and won't be present in logs
             progress.add_task(
                 "Validating BIDS dataset. This may take a while...", total=None
             )
@@ -113,7 +174,28 @@ def bids2tsv(
     dataset_tab = b2t2.index_dataset(bids_dir)
     dataset_df = dataset_tab.to_pandas()
 
-    dataset_df = dataset_df.query('ext in [".nii", ".nii.gz"]').copy()
+    if not dataset_df["suffix"].isin(mappings.BIDS.keys()).any():
+        log_error(
+            logger,
+            f"No image files with supported BIDS suffixes were found in {bids_dir}. "
+            "A BIDS metadata table could not be generated. "
+            "Please ensure your dataset includes at least one image file with a Neurobagel-supported BIDS suffix "
+            f"(Supported suffixes: {list(mappings.BIDS.keys())}).",
+        )
+
+    unsupported_suffixes = bids_utils.find_unsupported_image_suffixes(
+        dataset_df
+    )
+    if unsupported_suffixes:
+        logger.warning(
+            f"Image file suffixes unsupported by Neurobagel were found in the BIDS directory: {unsupported_suffixes}. "
+            f"These will be ignored. Supported BIDS suffixes: {list(mappings.BIDS.keys())}."
+        )
+
+    dataset_df = dataset_df[
+        dataset_df["suffix"].isin(mappings.BIDS.keys())
+    ].copy()
+
     dataset_df["path"] = dataset_df.apply(
         lambda row: (Path(row["root"]) / row["path"]).as_posix(), axis=1
     )
@@ -135,7 +217,7 @@ def pheno(
         ...,
         "--pheno",
         "-t",  # for tabular
-        help="The path to a phenotypic .tsv file",
+        help="Path to a phenotypic .tsv file",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -145,7 +227,7 @@ def pheno(
         ...,
         "--dictionary",
         "-d",
-        help="The path to the .json data dictionary corresponding to the phenotypic .tsv file.",
+        help="Path to the .json data dictionary corresponding to the phenotypic .tsv file.",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -156,23 +238,24 @@ def pheno(
         "--name",
         "-n",
         callback=pheno_utils.check_param_not_whitespace,
-        help="The full name of the dataset. "
+        help='Full name of the dataset, enclosed in quotes ("") if it includes spaces. '
         "This name will be displayed when users discover the dataset in a Neurobagel query. "
-        "For a dataset with BIDS data, the name should ideally match the dataset_description.json 'name' field. "
-        'Enclose in quotes, e.g.: --name "my dataset name"',
+        "For datasets with BIDS data, this name should ideally match the dataset_description.json 'name' field. "
+        '[italic]Example: --name "My Awesome Dataset"[/italic]',
     ),
     portal: str = typer.Option(
         None,
         "--portal",
         "-u",  # for URL
         callback=pheno_utils.validate_portal_uri,
-        help="URL (HTTP/HTTPS) to a website or page that describes the dataset and access instructions (if available).",
+        help="URL (HTTP/HTTPS) to a website or page with access instructions "
+        "and/or additional information about the dataset.",
     ),
     output: Path = typer.Option(
         "pheno.jsonld",
         "--output",
         "-o",
-        help="The path to the output .jsonld file.",
+        help="Path to the output .jsonld file.",
         file_okay=True,
         dir_okay=False,
         resolve_path=True,
@@ -192,22 +275,19 @@ def pheno(
             ),
             case_sensitive=False,
         ),
-        help="The name of the vocabulary configuration used to generate your data dictionary. "
+        help="Name of the vocabulary configuration used to generate your data dictionary in the annotation tool. "
         "If you are processing data for a Neurobagel subcommunity, choose the subcommunity name here. "
-        "This should be the same as the configuration name you selected in the annotation tool."
         f"{pheno_utils.additional_config_help_text()}",
+        rich_help_panel=OPTION_GROUP_NAMES["config"],
     ),
     overwrite: bool = overwrite_option(),
     verbosity: VerbosityLevel = verbosity_option(),
+    help_: bool = help_option(),
 ):
     """
-    Process a tabular phenotypic file (.tsv) that has been successfully annotated
-    with the Neurobagel annotation tool. The annotations are expected to be stored
-    in a data dictionary (.json).
+    Process a tabular phenotypic file (.tsv) that has been successfully annotated with the Neurobagel annotation tool, with annotations stored in a data dictionary (.json).
 
-    This command will create a valid, subject-level instance of the Neurobagel
-    graph data model for the provided phenotypic file in the .jsonld format.
-    You can upload this .jsonld file to the Neurobagel graph.
+    This command will create a valid, subject-level instance of the Neurobagel graph data model for the provided phenotypic file in the JSON-LD format. You can upload this .jsonld file to the Neurobagel graph.
     """
     file_utils.check_overwrite(output, overwrite)
 
@@ -272,20 +352,23 @@ def pheno(
                 _dx_vals = pheno_utils.get_transformed_values(
                     column_mapping["diagnosis"], _ses_pheno, data_dictionary
                 )
-                if not _dx_vals:
-                    pass
-                # NOTE: If the subject has both a diagnosis value and a value of healthy control, we assume the healthy control designation is more important
-                # and do not assign diagnoses to the subject
-                elif mappings.NEUROBAGEL["healthy_control"] in _dx_vals:
-                    session.isSubjectGroup = models.SubjectGroup(
-                        identifier=mappings.NEUROBAGEL["healthy_control"],
-                    )
-                else:
+                if _dx_vals:
                     session.hasDiagnosis = [
                         models.Diagnosis(identifier=_dx_val)
                         for _dx_val in _dx_vals
                     ]
 
+            if "subject_group" in column_mapping.keys():
+                _group_vals = pheno_utils.get_transformed_values(
+                    column_mapping["subject_group"],
+                    _ses_pheno,
+                    data_dictionary,
+                )
+                if _group_vals:
+                    session.isSubjectGroup = models.SubjectGroup(
+                        identifier=_group_vals[0]
+                    )
+
             if "age" in column_mapping.keys():
                 # NOTE: At the moment, our data model only supports a single age value per subject.
                 # To achieve this, we transform the values from ALL columns annotated as about age
@@ -334,8 +417,8 @@ def bids(
         ...,
         "--jsonld-path",
         "-p",  # for pheno
-        help="The path to the .jsonld file containing the phenotypic data for your dataset, created by the bagel pheno command. "
-        "This file may optionally also include the processing pipeline metadata for the dataset (created by the bagel derivatives command).",
+        help="Path to the .jsonld file containing the phenotypic data for your dataset, created using the 'bagel pheno' command. "
+        "This file may optionally also include the processing pipeline metadata for the dataset (created using the 'bagel derivatives' command).",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -345,8 +428,8 @@ def bids(
         ...,
         "--bids-table",
         "-b",
-        help="The path to a .tsv file containing the BIDS metadata for image files including 'sub', 'ses', 'suffix', and 'path' columns. "
-        "This file can be created using the bagel bids2tsv command.",
+        help="Path to a .tsv file containing the BIDS metadata for image files including 'sub', 'ses', 'suffix', and 'path' columns. "
+        "This file can be created using the 'bagel bids2tsv' command.",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -359,11 +442,13 @@ def bids(
         "--dataset-source-dir",
         "-s",
         callback=bids_utils.check_absolute_path,
-        help="The absolute path to the root directory of the dataset at the source location/file server. "
+        help="Absolute path to the root directory of the BIDS dataset at the source location/file server. "
         "If provided, this path will be combined with the subject and session IDs from the BIDS table "
         "to create absolute source paths to the imaging data for each subject and session.",
+        exists=False,
         file_okay=False,
         dir_okay=True,
+        resolve_path=False,
     ),
     # TODO: Should we rename the default output file to something more generic to account for the fact that
     # the file may also include derivatives data? e.g., dataset_bids.jsonld
@@ -371,23 +456,20 @@ def bids(
         "pheno_bids.jsonld",
         "--output",
         "-o",
-        help="The path to the output .jsonld file.",
+        help="Path to the output .jsonld file.",
         file_okay=True,
         dir_okay=False,
         resolve_path=True,
     ),
     overwrite: bool = overwrite_option(),
     verbosity: VerbosityLevel = verbosity_option(),
+    help_: bool = help_option(),
 ):
     """
-    Extract imaging metadata from a valid BIDS dataset and integrate it with
-    subjects' harmonized phenotypic data (from the bagel pheno command) and, optionally,
-    processing pipeline metadata (from the bagel derivatives command) in a single .jsonld file.
-    NOTE: Must be run AFTER the pheno command.
+    Extract and integrate imaging metadata from a BIDS dataset with harmonized subject phenotypic data (from 'bagel pheno') and, optionally, processing pipeline metadata (from 'bagel derivatives') in a single .jsonld file.
+    [red]NOTE: Must be run AFTER 'bagel pheno'.[/red]
 
-    This command will create a valid, subject-level instance of the Neurobagel
-    graph data model for the combined metadata in the .jsonld format.
-    You can upload this .jsonld file to the Neurobagel graph.
+    This command will create a valid, subject-level instance of the Neurobagel graph data model for the combined metadata in the JSON-LD format. You can upload this .jsonld file to the Neurobagel graph.
     """
 
     file_utils.check_overwrite(output, overwrite)
@@ -414,6 +496,33 @@ def bids(
     )
     bids_dataset = file_utils.load_tabular(bids_table, input_type="BIDS")
 
+    # NOTE: The BIDS table model validation will check for required columns and allowed values in the "suffix" column
+    # and error out for any problem. Because we want to ignore unsupported suffixes with a warning instead of just a validation error,
+    # we first check the suffix column separately and then remove any offending values.
+    # For our custom suffix-check to work, we need to ensure that the "suffix" column exists here.
+    if "suffix" in bids_dataset.columns:
+        if not bids_dataset["suffix"].isin(mappings.BIDS.keys()).any():
+            log_error(
+                logger,
+                f"No Neurobagel-supported BIDS suffixes found in BIDS table 'suffix' column: {bids_table}. "
+                "No imaging metadata could be added to the subject graph data. "
+                "Please ensure your dataset includes at least one image file with a Neurobagel-supported BIDS suffix "
+                f"(supported suffixes: {list(mappings.BIDS.keys())}).",
+            )
+
+        unsupported_suffixes = bids_utils.find_unsupported_image_suffixes(
+            bids_dataset
+        )
+        if unsupported_suffixes:
+            logger.warning(
+                f"BIDS table 'suffix' column contains image file suffixes unsupported by Neurobagel: {unsupported_suffixes}. "
+                f"These records will be ignored. Supported BIDS suffixes: {list(mappings.BIDS.keys())}."
+            )
+
+        bids_dataset = bids_dataset[
+            bids_dataset["suffix"].isin(mappings.BIDS.keys())
+        ].copy()
+
     bids_utils.validate_bids_table(bids_dataset)
 
     existing_subs_dict = model_utils.get_subject_instances(jsonld_dataset)
@@ -428,8 +537,12 @@ def bids(
     logger.info("Initial checks of inputs passed.")
 
     logger.info("Merging BIDS metadata with existing subject annotations...")
+
+    disable_progress_bar = verbosity == VerbosityLevel.ERROR
     for bids_sub_id in track(
-        bids_subject_ids, description="Processing BIDS subjects..."
+        bids_subject_ids,
+        description="Processing BIDS subjects...",
+        disable=disable_progress_bar,
     ):
         _bids_sub = bids_dataset[bids_dataset["sub"] == bids_sub_id]
         existing_subject = existing_subs_dict[bids_sub_id]
@@ -487,7 +600,7 @@ def bids(
     # This may be resolved with https://github.com/neurobagel/bagel-cli/issues/492.
     file_utils.save_jsonld(
         data={
-            **jsonld_context,
+            "@context": jsonld_context,
             **jsonld_dataset.model_dump(exclude_none=True),
         },
         filename=output,
@@ -500,7 +613,7 @@ def derivatives(
         ...,
         "--tabular",
         "-t",
-        help="The path to a .tsv containing subject-level processing pipeline status info. Expected to comply with the Nipoppy processing status file schema.",
+        help="Path to a .tsv containing subject-level processing pipeline status info. Expected to comply with the Nipoppy processing status file schema.",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -511,7 +624,7 @@ def derivatives(
         ...,
         "--jsonld-path",
         "-p",  # for pheno
-        help="The path to a .jsonld file containing the phenotypic data for your dataset, created by the bagel pheno command. This JSONLD may optionally also include the BIDS metadata for the dataset (created by the bagel bids command).",
+        help="Path to a .jsonld file containing the phenotypic data for your dataset, created using the 'bagel pheno' command. This file may optionally also include the BIDS metadata for the dataset (created using the 'bagel bids' command).",
         exists=True,
         file_okay=True,
         dir_okay=False,
@@ -521,23 +634,20 @@ def derivatives(
         "pheno_derivatives.jsonld",
         "--output",
         "-o",
-        help="The path to the output .jsonld file.",
+        help="Path to the output .jsonld file.",
         file_okay=True,
         dir_okay=False,
         resolve_path=True,
     ),
     overwrite: bool = overwrite_option(),
     verbosity: VerbosityLevel = verbosity_option(),
+    help_: bool = help_option(),
 ):
     """
-    Extract subject processing pipeline and derivative metadata from a tabular processing status file and
-    integrate them in a single .jsonld with subjects' harmonized phenotypic data (from the bagel pheno command) and optionally,
-    BIDS metadata (from the bagel bids command).
-    NOTE: Must be run AFTER the pheno command.
+    Extract subject processing pipeline and derivative metadata from a tabular processing status file and integrate them in a single .jsonld with harmonized subject phenotypic data (from 'bagel pheno') and optionally, BIDS metadata (from 'bagel bids').
+    [red]NOTE: Must be run AFTER 'bagel pheno'.[/red]
 
-    This command will create a valid, subject-level instance of the Neurobagel
-    graph data model for the combined metadata in the .jsonld format.
-    You can upload this .jsonld file to the Neurobagel graph.
+    This command will create a valid, subject-level instance of the Neurobagel graph data model for the combined metadata in the JSON-LD format. You can upload this .jsonld file to the Neurobagel graph.
     """
 
     file_utils.check_overwrite(output, overwrite)
@@ -633,7 +743,7 @@ def derivatives(
     # This may be resolved with https://github.com/neurobagel/bagel-cli/issues/492.
     file_utils.save_jsonld(
         data={
-            **jsonld_context,
+            "@context": jsonld_context,
             **jsonld_dataset.model_dump(exclude_none=True),
         },
         filename=output,
